@@ -195,8 +195,13 @@ show_bars (GtkTreeModel *mdl,
  				    &readelements, -1);
                 
                 gtk_tree_model_get (mdl, iter, size_col, &size, -1);
-                sizecstr = g_format_size_for_display (size);
-
+		
+		#if GLIB_CHECK_VERSION (2, 30, 0)
+			sizecstr = g_format_size (size);
+		#else
+			sizecstr = g_format_size_for_display (size);
+		#endif
+		
  		if (readelements == -1) {
 			gtk_tree_store_set (GTK_TREE_STORE (mdl), iter,
 				            COL_DIR_SIZE, sizecstr, -1);
@@ -220,8 +225,13 @@ show_bars (GtkTreeModel *mdl,
 		if (readelements != -1) {
 			gtk_tree_model_get (mdl, iter, size_col, &size,
 					    -1);
-			sizecstr = g_format_size_for_display (size);
-
+			
+			#if GLIB_CHECK_VERSION (2, 30, 0)
+				sizecstr = g_format_size (size);
+			#else
+				sizecstr = g_format_size_for_display (size);
+			#endif
+			
 			gtk_tree_store_set (GTK_TREE_STORE (mdl), iter,
 					    COL_H_PERC, 100.0,
 					    COL_DIR_SIZE, sizecstr, -1);
@@ -495,17 +505,6 @@ trash_file (GFile *file)
 	return TRUE;
 }
 
-gchar *
-baobab_mateconf_get_string_with_default (MateConfClient *client,
-				      const gchar *key,
-				      const gchar *def)
-{
-	gchar *val;
-
-	val = mateconf_client_get_string (client, key, NULL);
-	return val ? val : g_strdup (def);
-}
-
 gboolean
 baobab_help_display (GtkWindow   *parent,
 		     const gchar *file_name,
