@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -209,7 +209,12 @@ logview_update_statusbar (LogviewWindow *logview, LogviewLog *active)
 
   modified = g_strdup_printf (_("last update: %s"), timestring_utf8);
 
-  size = g_format_size_for_display (logview_log_get_file_size (active));
+  #if GLIB_CHECK_VERSION (2, 30, 0)
+    size = g_format_size (logview_log_get_file_size (active));
+  #else
+    size = g_format_size_for_display (logview_log_get_file_size (active));
+  #endif
+  
   statusbar_text = g_strdup_printf (_("%d lines (%s) - %s"), 
                                     logview_log_get_cached_lines_number (active),
                                     size, modified);
