@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License  
  * along with this program; if not, write to the Free Software  
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,10 +26,10 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
+#include <gio/gio.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
-#include <mateconf/mateconf-client.h>
 
 #include "gdict-applet.h"
 #include "gdict-about.h"
@@ -53,9 +53,8 @@ struct _GdictAppletPrivate
   guint size;
   GtkOrientation orient;
   
-  MateConfClient *mateconf_client;
-  guint notify_id;
-  guint font_notify_id;
+  GSettings *settings;
+  GSettings *desktop_settings;
 
   gchar *database;
   gchar *strategy;
@@ -79,6 +78,8 @@ struct _GdictAppletPrivate
   GtkWidget *frame;
   GtkWidget *defbox;
 
+  GtkActionGroup* context_menu_action_group;
+
   guint idle_draw_id;
 
   GdkPixbuf *icon;
@@ -255,24 +256,19 @@ static void
 gdict_applet_set_menu_items_sensitive (GdictApplet *applet,
 				       gboolean     is_sensitive)
 {
-  MateComponentUIComponent *popup_component;
-  
-  popup_component = mate_panel_applet_get_popup_component (MATE_PANEL_APPLET (applet));
-  if (!MATECOMPONENT_IS_UI_COMPONENT (popup_component))
-    return;
+  GtkAction *action;
 
-  matecomponent_ui_component_set_prop (popup_component,
-		  		"/commands/Clear",
-				"sensitive", (is_sensitive ? "1" : "0"),
-				NULL);
-  matecomponent_ui_component_set_prop (popup_component,
-		  		"/commands/Print",
-				"sensitive", (is_sensitive ? "1" : "0"),
-				NULL);
-  matecomponent_ui_component_set_prop (popup_component,
-		  		"/commands/Save",
-				"sensitive", (is_sensitive ? "1" : "0"),
-				NULL);
+  action = gtk_action_group_get_action (applet->priv->context_menu_action_group,
+                                        "DictionaryClear");
+  gtk_action_set_sensitive (action, is_sensitive);
+  action = gtk_action_group_get_action (applet->priv->context_menu_action_group,
+                                        "DictionaryPrint");
+  gtk_action_set_sensitive (action, is_sensitive);
+  action = gtk_action_group_get_action (applet->priv->context_menu_action_group,
+                                        "DictionarySave");
+  gtk_action_set_sensitive (action, is_sensitive);
+
+	return;
 }
 
 static gboolean
@@ -671,9 +667,8 @@ gdict_applet_error_cb (GdictContext *context,
 }
 
 static void
-gdict_applet_cmd_lookup (MateComponentUIComponent *component,
-			 GdictApplet       *applet,
-			 const gchar       *cname)
+gdict_applet_cmd_lookup (GtkAction *action,
+			 GdictApplet       *applet)
 {
   GdictAppletPrivate *priv = applet->priv;
   gchar *text = NULL;;
@@ -692,25 +687,29 @@ gdict_applet_cmd_lookup (MateComponentUIComponent *component,
 }
 
 static void
-gdict_applet_cmd_clear (MateComponentUIComponent *component,
-			GdictApplet       *applet,
-			const gchar       *cname)
+gdict_applet_cmd_clear (GtkAction *action,
+			GdictApplet       *applet)
 {
   clear_cb (NULL, applet);
 }
 
 static void
-gdict_applet_cmd_print (MateComponentUIComponent *component,
-			GdictApplet       *applet,
-			const gchar       *cname)
+gdict_applet_cmd_print (GtkAction *action,
+			GdictApplet       *applet)
 {
   print_cb (NULL, applet);
 }
 
 static void
-gdict_applet_cmd_preferences (MateComponentUIComponent *component,
-			      GdictApplet       *applet,
-			      const gchar       *cname)
+gdict_applet_cmd_save (GtkAction *action,
+			GdictApplet       *applet)
+{
+  save_cb (NULL, applet);
+}
+
+static void
+gdict_applet_cmd_preferences (GtkAction *action,
+			      GdictApplet       *applet)
 {
   gdict_show_pref_dialog (GTK_WIDGET (applet),
   			  _("Dictionary Preferences"),
@@ -718,17 +717,15 @@ gdict_applet_cmd_preferences (MateComponentUIComponent *component,
 }
 
 static void
-gdict_applet_cmd_about (MateComponentUIComponent *component,
-			GdictApplet       *applet,
-			const gchar       *cname)
+gdict_applet_cmd_about (GtkAction *action,
+			GdictApplet       *applet)
 {
   gdict_show_about_dialog (GTK_WIDGET (applet));
 }
 
 static void
-gdict_applet_cmd_help (MateComponentUIComponent *component,
-		       GdictApplet       *applet,
-		       const gchar       *cname)
+gdict_applet_cmd_help (GtkAction *action,
+		       GdictApplet       *applet)
 {
   GError *err = NULL;
 
@@ -850,12 +847,11 @@ gdict_applet_set_database (GdictApplet *applet,
   
   g_free (priv->database);
 
-  if (database)
+  if (database != NULL && *database != '\0')
     priv->database = g_strdup (database);
   else
-    priv->database = gdict_mateconf_get_string_with_default (priv->mateconf_client,
-							  GDICT_MATECONF_DATABASE_KEY,
-							  GDICT_DEFAULT_DATABASE);
+    priv->database = g_settings_get_string (priv->settings,
+							  GDICT_SETTINGS_DATABASE_KEY);
   if (priv->defbox)
     gdict_defbox_set_database (GDICT_DEFBOX (priv->defbox),
 			       priv->database);
@@ -869,12 +865,11 @@ gdict_applet_set_strategy (GdictApplet *applet,
   
   g_free (priv->strategy);
 
-  if (strategy)
+  if (strategy != NULL && *strategy != '\0')
     priv->strategy = g_strdup (strategy);
   else
-    priv->strategy = gdict_mateconf_get_string_with_default (priv->mateconf_client,
-							  GDICT_MATECONF_STRATEGY_KEY,
-							  GDICT_DEFAULT_STRATEGY);
+    priv->strategy = g_settings_get_string (priv->settings,
+							  GDICT_SETTINGS_STRATEGY_KEY);
 }
 
 static GdictContext *
@@ -939,12 +934,11 @@ gdict_applet_set_print_font (GdictApplet *applet,
 
   g_free (priv->print_font);
 
-  if (print_font)
+  if (print_font != NULL && *print_font != '\0')
     priv->print_font = g_strdup (print_font);
   else
-    priv->print_font = gdict_mateconf_get_string_with_default (priv->mateconf_client,
-							    GDICT_MATECONF_PRINT_FONT_KEY,
-							    GDICT_DEFAULT_PRINT_FONT);
+    priv->print_font = g_settings_get_string (priv->settings,
+							    GDICT_SETTINGS_PRINT_FONT_KEY);
 }
 
 static void
@@ -955,12 +949,11 @@ gdict_applet_set_defbox_font (GdictApplet *applet,
 
   g_free (priv->defbox_font);
 
-  if (defbox_font)
+  if (defbox_font != NULL && *defbox_font != '\0')
     priv->defbox_font = g_strdup (defbox_font);
   else
-    priv->defbox_font = gdict_mateconf_get_string_with_default (priv->mateconf_client,
-							     DOCUMENT_FONT_KEY,
-							     GDICT_DEFAULT_DEFBOX_FONT);
+    priv->defbox_font = g_settings_get_string (priv->desktop_settings,
+							     DOCUMENT_FONT_KEY);
 
   if (priv->defbox)
     gdict_defbox_set_font_name (GDICT_DEFBOX (priv->defbox),
@@ -1016,59 +1009,40 @@ gdict_applet_set_source_name (GdictApplet *applet,
 
   g_free (priv->source_name);
 
-  if (source_name)
+  if (source_name != NULL && *source_name != '\0')
     priv->source_name = g_strdup (source_name);
   else
-    priv->source_name = gdict_mateconf_get_string_with_default (priv->mateconf_client,
-							     GDICT_MATECONF_SOURCE_KEY,
-							     GDICT_DEFAULT_SOURCE_NAME);
+    priv->source_name = g_settings_get_string (priv->settings,
+							     GDICT_SETTINGS_SOURCE_KEY);
   
   context = get_context_from_loader (applet);
   gdict_applet_set_context (applet, context);
 }
 
 static void
-gdict_applet_mateconf_notify_cb (MateConfClient *client,
-			      guint        cnxn_id,
-			      MateConfEntry  *entry,
-			      gpointer     user_data)
+gdict_applet_settings_changed_cb (GSettings *settings,
+                  const gchar *key, GdictApplet *applet)
 {
-  GdictApplet *applet = GDICT_APPLET (user_data);
 
-  if (strcmp (entry->key, GDICT_MATECONF_PRINT_FONT_KEY) == 0)
+  if (g_strcmp0 (key, GDICT_SETTINGS_PRINT_FONT_KEY) == 0)
     {
-      if (entry->value && (entry->value->type == MATECONF_VALUE_STRING))
-        gdict_applet_set_print_font (applet, mateconf_value_get_string (entry->value));
-      else
-        gdict_applet_set_print_font (applet, GDICT_DEFAULT_PRINT_FONT);
+        gdict_applet_set_print_font (applet, NULL);
     }
-  else if (strcmp (entry->key, GDICT_MATECONF_SOURCE_KEY) == 0)
+  else if (g_strcmp0 (key, GDICT_SETTINGS_SOURCE_KEY) == 0)
     {
-      if (entry->value && (entry->value->type == MATECONF_VALUE_STRING))
-        gdict_applet_set_source_name (applet, mateconf_value_get_string (entry->value));
-      else
-        gdict_applet_set_source_name (applet, GDICT_DEFAULT_SOURCE_NAME);
+        gdict_applet_set_source_name (applet, NULL);
     }
-  else if (strcmp (entry->key, GDICT_MATECONF_DATABASE_KEY) == 0)
+  else if (g_strcmp0 (key, GDICT_SETTINGS_DATABASE_KEY) == 0)
     {
-      if (entry->value && (entry->value->type == MATECONF_VALUE_STRING))
-        gdict_applet_set_database (applet, mateconf_value_get_string (entry->value));
-      else
-        gdict_applet_set_database (applet, GDICT_DEFAULT_DATABASE);
+        gdict_applet_set_database (applet, NULL);
     }
-  else if (strcmp (entry->key, GDICT_MATECONF_STRATEGY_KEY) == 0)
+  else if (g_strcmp0 (key, GDICT_SETTINGS_STRATEGY_KEY) == 0)
     {
-      if (entry->value && (entry->value->type == MATECONF_VALUE_STRING))
-        gdict_applet_set_strategy (applet, mateconf_value_get_string (entry->value));
-      else
-        gdict_applet_set_strategy (applet, GDICT_DEFAULT_STRATEGY);
+        gdict_applet_set_strategy (applet, NULL);
     }
-  else if (strcmp (entry->key, DOCUMENT_FONT_KEY) == 0)
+  else if (g_strcmp0 (key, DOCUMENT_FONT_KEY) == 0)
     {
-      if (entry->value && (entry->value->type == MATECONF_VALUE_STRING))
-        gdict_applet_set_defbox_font (applet, mateconf_value_get_string (entry->value));
-      else
-        gdict_applet_set_defbox_font (applet, GDICT_DEFAULT_DEFBOX_FONT);
+        gdict_applet_set_defbox_font (applet, NULL);
     }
 }
 
@@ -1081,23 +1055,32 @@ gdict_applet_finalize (GObject *object)
   if (priv->idle_draw_id)
     g_source_remove (priv->idle_draw_id);
 
-  if (priv->notify_id)
-    mateconf_client_notify_remove (priv->mateconf_client, priv->notify_id);
+  if (priv->context_menu_action_group)
+    {
+      g_object_unref (priv->context_menu_action_group);
+      priv->context_menu_action_group = NULL;
+    }
+
+  if (priv->settings != NULL)
+    {
+      g_object_unref (priv->settings);
+      priv->settings = NULL;
+    }
+
+  if (priv->desktop_settings != NULL)
+    {
+      g_object_unref (priv->desktop_settings);
+      priv->desktop_settings = NULL;
+    }
 
-  if (priv->font_notify_id)
-    mateconf_client_notify_remove (priv->mateconf_client, priv->font_notify_id);
-  
-  if (priv->mateconf_client)
-    g_object_unref (priv->mateconf_client);
-  
   if (priv->context)
     {
       if (priv->lookup_start_id)
         {
           g_signal_handler_disconnect (priv->context, priv->lookup_start_id);
-	  g_signal_handler_disconnect (priv->context, priv->lookup_end_id);
-	  g_signal_handler_disconnect (priv->context, priv->error_id);
-	}
+          g_signal_handler_disconnect (priv->context, priv->lookup_end_id);
+          g_signal_handler_disconnect (priv->context, priv->error_id);
+        }
 
       g_object_unref (priv->context);
     }
@@ -1139,7 +1122,6 @@ gdict_applet_init (GdictApplet *applet)
 {
   GdictAppletPrivate *priv;
   gchar *data_dir;
-  GError *mateconf_error;
 
   priv = GDICT_APPLET_GET_PRIVATE (applet);
   applet->priv = priv;
@@ -1156,52 +1138,16 @@ gdict_applet_init (GdictApplet *applet)
   
   mate_panel_applet_set_flags (MATE_PANEL_APPLET (applet),
 			  MATE_PANEL_APPLET_EXPAND_MINOR);
-  
-  /* get the default mateconf client */
-  if (!priv->mateconf_client)
-    priv->mateconf_client = mateconf_client_get_default ();
-  
-  mateconf_error = NULL;
-  mateconf_client_add_dir (priv->mateconf_client,
-  			GDICT_MATECONF_DIR,
-  			MATECONF_CLIENT_PRELOAD_ONELEVEL,
-  			&mateconf_error);
-  if (mateconf_error)
-    {
-      gdict_show_gerror_dialog (NULL,
-		                _("Unable to connect to MateConf"),
-		                mateconf_error);
-      mateconf_error = NULL;
-    }
-  
-  priv->notify_id = mateconf_client_notify_add (priv->mateconf_client,
-		  			     GDICT_MATECONF_DIR,
-					     gdict_applet_mateconf_notify_cb,
-					     applet, NULL,
-					     &mateconf_error);
-  if (mateconf_error)
-    {
-      gdict_show_gerror_dialog (NULL,
-		                _("Unable to get notification for preferences"),
-		                mateconf_error);
 
-      mateconf_error = NULL;
-    }
-  
-  priv->font_notify_id =  mateconf_client_notify_add (priv->mateconf_client,
-		  				   DOCUMENT_FONT_KEY,
-						   gdict_applet_mateconf_notify_cb,
-						   applet, NULL,
-						   &mateconf_error);
-  if (mateconf_error)
-    {
-      gdict_show_gerror_dialog (NULL,
-                               _("Unable to get notification for the document font"),
-                               mateconf_error);
+  priv->settings = g_settings_new (GDICT_SETTINGS_SCHEMA);
+  priv->desktop_settings = g_settings_new (DESKTOP_SETTINGS_SCHEMA);
+
+  g_signal_connect (priv->settings, "changed",
+                    G_CALLBACK (gdict_applet_settings_changed_cb), applet);
+
+  g_signal_connect (priv->desktop_settings, "changed",
+                    G_CALLBACK (gdict_applet_settings_changed_cb), applet);
 
-      mateconf_error = NULL;
-    }
-  
 #ifndef GDICT_APPLET_STAND_ALONE
   mate_panel_applet_set_background_widget (MATE_PANEL_APPLET (applet),
 		  		      GTK_WIDGET (applet));
@@ -1237,25 +1183,35 @@ gdict_applet_init (GdictApplet *applet)
   /* force first draw */
   gdict_applet_draw (applet);
 
-  /* force retrieval of the configuration from MateConf */
+  /* force retrieval of the configuration from settings */
   gdict_applet_set_source_name (applet, NULL);
   gdict_applet_set_defbox_font (applet, NULL);
   gdict_applet_set_print_font (applet, NULL);
 }
 
 #ifndef GDICT_APPLET_STAND_ALONE
-static const MateComponentUIVerb gdict_applet_menu_verbs[] =
-{
-  MATECOMPONENT_UI_UNSAFE_VERB ("LookUp", gdict_applet_cmd_lookup),
-  
-  MATECOMPONENT_UI_UNSAFE_VERB ("Clear", gdict_applet_cmd_clear),
-  MATECOMPONENT_UI_UNSAFE_VERB ("Print", gdict_applet_cmd_print),
-  
-  MATECOMPONENT_UI_UNSAFE_VERB ("Preferences", gdict_applet_cmd_preferences),
-  MATECOMPONENT_UI_UNSAFE_VERB ("Help", gdict_applet_cmd_help),
-  MATECOMPONENT_UI_UNSAFE_VERB ("About", gdict_applet_cmd_about),
-
-  MATECOMPONENT_UI_VERB_END
+static const GtkActionEntry gdict_applet_menu_actions[] = {
+  {"DictionaryLookup", GTK_STOCK_FIND, N_("_Look Up Selected Text"),
+    NULL, NULL,
+    G_CALLBACK (gdict_applet_cmd_lookup) },
+  {"DictionaryClear", GTK_STOCK_CLEAR, N_("Cl_ear"),
+    NULL, NULL,
+    G_CALLBACK (gdict_applet_cmd_clear) },
+  {"DictionaryPrint", GTK_STOCK_PRINT, N_("_Print"),
+    NULL, NULL,
+    G_CALLBACK (gdict_applet_cmd_print) },
+  {"DictionarySave", GTK_STOCK_SAVE, N_("_Save"),
+    NULL, NULL,
+    G_CALLBACK (gdict_applet_cmd_save) },
+  {"DictionaryPreferences", GTK_STOCK_PREFERENCES, N_("Preferences"),
+    NULL, NULL,
+    G_CALLBACK (gdict_applet_cmd_preferences) },
+  {"DictionaryHelp", GTK_STOCK_HELP, N_("_Help"),
+    NULL, NULL,
+    G_CALLBACK (gdict_applet_cmd_help) },
+  {"DictionaryAbout", GTK_STOCK_ABOUT, N_("_About"),
+    NULL, NULL,
+    G_CALLBACK (gdict_applet_cmd_about) },
 };
 
 static gboolean
@@ -1264,22 +1220,29 @@ gdict_applet_factory (MatePanelApplet *applet,
 		      gpointer     data)
 {
   gboolean retval = FALSE;
+  gchar *ui_path;
+  GdictApplet *dictionary_applet = GDICT_APPLET (applet);
+  GdictAppletPrivate *priv = dictionary_applet->priv;
 
-  if (((!strcmp (iid, "OAFIID:MATE_DictionaryApplet")) ||
-       (!strcmp (iid, "OAFIID:MATE_GDictApplet"))) &&
-      gdict_create_data_dir ())
+  if (((!strcmp (iid, "DictionaryApplet"))) && gdict_create_data_dir ())
     {
       /* Set up the menu */
-      mate_panel_applet_setup_menu_from_file (applet, UIDATADIR,
-					 "MATE_DictionaryApplet.xml",
-					 NULL,
-					 gdict_applet_menu_verbs,
-					 applet);
+      priv->context_menu_action_group = gtk_action_group_new ("Dictionary Applet Actions");
+      gtk_action_group_set_translation_domain(priv->context_menu_action_group,
+                                              GETTEXT_PACKAGE);
+      gtk_action_group_add_actions(priv->context_menu_action_group,
+								gdict_applet_menu_actions,
+								G_N_ELEMENTS (gdict_applet_menu_actions),
+								applet);
+      ui_path = g_build_filename(PKGDATADIR, "dictionary-applet-menu.xml", NULL);
+      mate_panel_applet_setup_menu_from_file (applet, ui_path,
+                                              priv->context_menu_action_group);
+      g_free (ui_path);
 
       gtk_widget_show (GTK_WIDGET (applet));
 
       /* set the menu items insensitive */
-      gdict_applet_set_menu_items_sensitive (GDICT_APPLET (applet), FALSE);
+      gdict_applet_set_menu_items_sensitive (dictionary_applet, FALSE);
       
       retval = TRUE;
     }
@@ -1288,10 +1251,9 @@ gdict_applet_factory (MatePanelApplet *applet,
 }
 
 /* this defines the main () for the applet */
-MATE_PANEL_APPLET_MATECOMPONENT_FACTORY ("OAFIID:MATE_DictionaryApplet_Factory",
+MATE_PANEL_APPLET_OUT_PROCESS_FACTORY ("DictionaryAppletFactory",
 			     GDICT_TYPE_APPLET,
 			     "mate-dictionary-applet",
-			     VERSION,
 			     gdict_applet_factory,
 			     NULL);
 
